@@ -12,7 +12,7 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(check_int_range check_natural_range
 	check_number_range check_percent_range check_positive_natural_range);
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # ... -2, -1, 0, 1, 2, ...
 sub check_int_range {
@@ -354,6 +354,90 @@ Returns undef.
  # Output like:
  # #Error [...Range.pm:?] Parameter 'key' must be a number between 1 and 10.
 
+=head1 EXAMPLE7
+
+=for comment filename=check_percent_range_ok.pl
+
+ use strict;
+ use warnings;
+
+ use Mo::utils::Number::Range qw(check_percent_range);
+
+ my $self = {
+         'key' => '10%',
+ };
+ check_percent_range($self, 'key', 1.1, 11);
+
+ # Print out.
+ print "ok\n";
+
+ # Output:
+ # ok
+
+=head1 EXAMPLE8
+
+=for comment filename=check_percent_range_fail.pl
+
+ use strict;
+ use warnings;
+
+ $Error::Pure::TYPE = 'Error';
+
+ use Mo::utils::Number::Range qw(check_percent_range);
+
+ my $self = {
+         'key' => 11,
+ };
+ check_percent_range($self, 'key', 1, 10);
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # #Error [...Range.pm:?] Parameter 'key' has bad percent value (missing %).
+
+=head1 EXAMPLE9
+
+=for comment filename=check_positive_natural_range_ok.pl
+
+ use strict;
+ use warnings;
+
+ use Mo::utils::Number::Range qw(check_positive_natural_range);
+
+ my $self = {
+         'key' => '10',
+ };
+ check_positive_natural_range($self, 'key', 1.1, 11);
+
+ # Print out.
+ print "ok\n";
+
+ # Output:
+ # ok
+
+=head1 EXAMPLE10
+
+=for comment filename=check_positive_natural_range_fail.pl
+
+ use strict;
+ use warnings;
+
+ $Error::Pure::TYPE = 'Error';
+
+ use Mo::utils::Number::Range qw(check_positive_natural_range);
+
+ my $self = {
+         'key' => -2,
+ };
+ check_positive_natural_range($self, 'key', 1, 10);
+
+ # Print out.
+ print "ok\n";
+
+ # Output like:
+ # #Error [...Range.pm:?] Parameter 'key' must be a positive natural number.
+
 =head1 DEPENDENCIES
 
 L<Error::Pure>,
@@ -397,6 +481,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
